@@ -1,4 +1,5 @@
 import logging
+import warnings
 
 from boto3.resources.base import ServiceResource
 
@@ -10,8 +11,8 @@ class AIOBoto3ServiceResource(ServiceResource):
         return self
 
     async def __aexit__(self, exc_type, exc_val, exc_tb):
-        await self.meta.client.close()
-        return False
+        await self.meta.client.__aexit__(exc_type, exc_val, exc_tb)
 
     def close(self):
+        warnings.warn("This should not be called anymore", DeprecationWarning)
         return self.meta.client.close()
